###################################################################################################
# zmsfile.py
#
# Implementation of class ZMSFile (see below).
###################################################################################################

# Imports.
from Globals import HTMLFile, Persistent
from OFS.Folder import Folder
from sys import *
import string 
import urllib
# Product imports.
from _metadata import Metadata
from zmsobject import ZMSObject
import _blobfields
import _fileutil
import _globals


###################################################################################################
###################################################################################################
###   
###   C o n s t r u c t o r ( s )
###   
###################################################################################################
###################################################################################################

manage_addZMSFileForm = HTMLFile('manage_addzmsfileform', globals()) 
def manage_addZMSFile(self, lang, manage_lang, _sort_id, REQUEST, RESPONSE):
  """ manage_addZMSFile """
    
  if REQUEST['btn'] == self.getLangStr('BTN_INSERT',manage_lang):
    
    ##### Create ####
    obj = ZMSFile(self.getNewId(),_sort_id+1)
    self._setObject(obj.id, obj)
        
    oItem = getattr(self,obj.id)
    ##### Object State ####
    oItem.setObjStateNew(REQUEST)
    ##### Init Properties ####
    oItem.manage_changeProperties(lang,manage_lang,REQUEST,RESPONSE)
    ##### VersionManager ####
    oItem.onChangeObj(REQUEST)

    ##### Normalize Sort-IDs ####
    self.normalizeSortIds()
    
    # Return with message.
    message = self.getLangStr('MSG_INSERTED',manage_lang)%obj.display_type(REQUEST)
    RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s#_%s'%(self.absolute_url(),lang,manage_lang,urllib.quote(message),obj.id))
                
  else:         
    RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s'%(self.absolute_url(),lang,manage_lang))



###################################################################################################
###################################################################################################
###   
###   C l a s s
###   
###################################################################################################
###################################################################################################
class ZMSFile(ZMSObject, Folder, Metadata): 
        
    # Properties.
    # -----------
    meta_type = 'ZMSFile'
    icon = "misc_/zms/zmsfile.gif"
    icon_disabled = 'misc_/zms/zmsfile_disabled.gif'

    # Management Options.
    # -------------------
    manage_options = ( 
	{'label': 'TAB_EDIT',       'action': 'manage_main'},
	{'label': 'TAB_REFERENCES', 'action': 'manage_RefForm'},
	{'label': 'TAB_HISTORY',    'action': 'manage_UndoForm'},
	{'label': 'TAB_PREVIEW',    'action': 'preview_html'}, # empty string defaults to index_html
	)

    # Management Permissions.
    # -----------------------
    __authorPermissions__ = (
		'manage','manage_main',
		'manage_moveObjUp','manage_moveObjDown',
		'manage_cutObjects','manage_copyObjects','manage_pasteObjs',
		'manage_changeProperties',
		'manage_rollbackVersionChanges','manage_requestVersionChanges',
		)
    __editorPermissions__ = (
		'manage_commitVersionChanges',
		)
    __administratorPermissions__ = (
		)
    __ac_permissions__=(
		('ZMS Author', __authorPermissions__),
		('ZMS Editor', __editorPermissions__),
		('ZMS Administrator', __administratorPermissions__),
		)

    # Properties.
    # -----------
    __obj_attrs__ = {
        # Changed by
        'change_uid':{'datatype':'LangString','xml':0,'lang_inherit':_globals.LI_FORBIDDEN},
        'change_dt':{'datatype':'LangDateTime','xml':0,'lang_inherit':_globals.LI_FORBIDDEN},
        # Properties
        'sort_id':{'datatype':'string','xml':0},
        'active':{'datatype':'LangInt','type':'checkbox','lang_inherit':_globals.LI_OBLIGATE},
        'attr_active_start':{'datatype':'LangDateTime','lang_inherit':_globals.LI_OBLIGATE},
        'attr_active_end':{'datatype':'LangDateTime','lang_inherit':_globals.LI_OBLIGATE},
        'title':{'datatype':'LangString','size':40},
        'titleshort':{'datatype':'LangString','size':20},
        'file':{'datatype':'LangFile'},
        # Meta-Data
        'attr_dc_coverage':{'datatype':'string'},
        # Meta-Dictionaries
        '$metadict':{'datatype':'MetaDict'},
    }


    # Management Interface.
    # ---------------------
    manage_main = HTMLFile('dtml/zmsfile/manage_main',globals()) 


    """
    ###############################################################################################    
    #
    #   CONSTRUCTOR
    #
    ###############################################################################################    
    """

    ###############################################################################################
    # ZMSFile.recurse_updateVersion:
    #
    # Update version.
    ###############################################################################################
    def recurse_updateVersion(self, lang, manage_lang, REQUEST):
        sMessage = ''
        
        # Process
        try:
            delattr(self,'format')
        except:
            pass
        
        # Process ZMSFile.
        try: delattr(self,'file')
        except: pass
        try: delattr(self,'src')
        except: pass

        # ---------------------------------------------------------------------
        # 26.11.2001 - 0.8 to 0.9: 
        # Meta-Dictionaries multilingual
        # ---------------------------------------------------------------------
        for s_attr in self.getMetadictAttrs(self.meta_type):
          if hasattr(self,s_attr):
            for s_lang in self.getLanguages():
              setattr(self,'%s_%s'%(s_attr,s_lang),getattr(self,s_attr))
            try: delattr(self,s_attr)
            except: pass
            
        # ---------------------------------------------------------------------
        # 11.01.2002 - 0.9 to 1.0: 
        # Blobs.
        # ---------------------------------------------------------------------
        _blobfields.synchronizeBlobFields(self)

        # Process super-objects.
        sMessage = sMessage + ZMSObject.recurse_updateVersion(self,lang,manage_lang,REQUEST)
        
        # Return with message.
        return sMessage


    # ---------------------------------------------------------------------------------------------
    #  ZMSFile.getLinkList: 
    #
    #  Returns ZMSFile as link-URL.
    # ---------------------------------------------------------------------------------------------
    def getLinkList(self,REQUEST, allow_none=0):
      rtn = []
      append = 1
      append = append and self.isCommitted(REQUEST) # Object has been committed.
      append = append and self.isActive(REQUEST) # Object is active.
      append = append and not self.isResource(REQUEST) # Object is not resource.
      if append:         
        dct = {}
        dct['internal'] = 1
        dct['src'] = self
        dct['dst'] = self
        if self.getFile(REQUEST) is None:
          dct['url'] = ''
        else:
          dct['url'] = self.getFile(REQUEST).getHref(REQUEST)
        dct['title'] = self.getTitle(REQUEST)
        dct['description'] = ''
        rtn.extend([dct])
      return rtn


    """
    ###############################################################################################    
    #
    #   Properties
    #
    ###############################################################################################    
    """
    
    ###############################################################################################
    #  ZMSFile.manage_changeProperties: 
    #
    #  Change file properties.
    ###############################################################################################
    def manage_changeProperties(self, lang, manage_lang, REQUEST, RESPONSE):
        """ ZMSFile.manage_changeProperties """
        
        message = ''
        if REQUEST.get('btn','') != self.getLangStr('BTN_CANCEL',manage_lang):
        
          ##### Object State ####
          self.setObjStateModified(REQUEST)
            
          ##### Properties ####
          # Title.
          self.setReqProperty('title',REQUEST)
          self.setReqProperty('titleshort',REQUEST)
          # Active.
          self.setReqProperty('active',REQUEST)
          self.setReqProperty('attr_active_start',REQUEST)
          self.setReqProperty('attr_active_end',REQUEST)
          # File.
          self.setReqProperty('file',REQUEST)
          file = self.getFile(REQUEST)
          if file is not None:
            if len(self.getObjProperty('title',REQUEST)) == 0:
              self.setObjProperty('title',getattr(file,'filename',''),lang)
            if len(self.getObjProperty('titleshort',REQUEST)) == 0:
              self.setObjProperty('titleshort',getattr(file,'filename',''),lang)
              
          ##### Blobs ####
          _blobfields.synchronizeBlobFields(self)
          
          ##### Metadata ####
          self.setMetadata(lang,manage_lang,REQUEST)
          
          ##### VersionManager ####
          self.onChangeObj(REQUEST)
          
          ##### Message ####
          message = self.getLangStr('MSG_CHANGED',manage_lang)
          
        # Return with message.
        self.checkIn(REQUEST)
        return RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s#_%s'%(self.getParentNode().absolute_url(),lang,manage_lang,urllib.quote(message),self.id))


    # ---------------------------------------------------------------------------------------------
    #  ZMSFile.isPageElement:
    # ---------------------------------------------------------------------------------------------
    def isPageElement(self): return 1

    # ---------------------------------------------------------------------------------------------
    #	ZMSFile.getTitle
    # ---------------------------------------------------------------------------------------------
    def getTitle(self,REQUEST): return self.getObjProperty('title',REQUEST)

    # ---------------------------------------------------------------------------------------------
    #	ZMSFile.getTitlealt
    # ---------------------------------------------------------------------------------------------
    def getTitlealt(self,REQUEST): return self.getObjProperty('titleshort',REQUEST)

    # ---------------------------------------------------------------------------------------------
    #	ZMSFile.getFile
    # ---------------------------------------------------------------------------------------------
    def getFile(self,REQUEST): return self.getObjProperty('file',REQUEST)


    #	ZMSFile.getMimeTypeIcon:
    #
    #	DEPRECATED: MIME-type icon.

    def getMimeTypeIcon(self,REQUEST): 
      f = self.getFile(REQUEST)
      return '<img src="%s" border="0" alt="%s">'%(f.getMimeTypeIconSrc(),f.getContentType())


    #	ZMSFile.getContentType:
    #
    #	DEPRECATED: Mime-Type.
    
    def getContentType(self,REQUEST): 
      f = self.getFile(REQUEST)
      return f.getContentType()


    # 	ZMSFile.getDataSizeStr: 
    #
    #	Display string for file-size.

    def getDataSizeStr(self, REQUEST): 
      f = self.getFile(REQUEST)
      return f.getDataSizeStr()

               
    """
    ###############################################################################################    
    ###  
    ###  HTML-Darstellung 
    ### 
    ###############################################################################################    
    """    
    
    # preload display interface
    rendershort_default = HTMLFile('dtml/zmsfile/render_default', globals()) 
    rendershort_print = HTMLFile('dtml/zmsfile/render_print', globals()) 
    
    # ------------------------------------------------------------------------------------------
    #  ZMSFile.renderShort:
    #
    #  Renders short presentation of File.
    # ------------------------------------------------------------------------------------------
    def renderShort(self, REQUEST):
      # Retrieve properties.
      file = self.getFile(REQUEST)
      url = None
      if file is not None:
        url = file.getHref(REQUEST)
      html = self.rendershort_default(self,url=url,REQUEST=REQUEST)
      # Process html <form>-tags.
      html = _globals.form_quote(html,REQUEST)
      # Return <html>.
      return html

    # ------------------------------------------------------------------------------------------
    #  ZMSFile.printHtml:
    #
    #  Renders print presentation of a File.
    # ------------------------------------------------------------------------------------------
    def printHtml(self, level, sectionize, sectionizer, REQUEST):
      # Retrieve properties.
      file = self.getFile(REQUEST)
      url = None
      if file is not None:
        url = file.getHref(REQUEST)
      # Return <html>-presentation.
      return self.rendershort_print(self,url=url,REQUEST=REQUEST)

###################################################################################################
